# MultiDiffusion: Fusing Diffusion Paths for Controlled Image Generation
文生图功能：MultiDiffusion应用于生成高质量和多样化的图像，这些图像符合用户提供的控件，例如所需的纵横比（例如全景）。

https://huggingface.co/docs/diffusers/api/pipelines/stable_diffusion/panorama